#Set working directory!
setwd("D:/Barbourofelid paper/JVP/Revisions the 2nd/BayesTraits/TNT_synaps_only")
#load packages
library(tracerer)
library(phytools)
library("devtools")
install_github("rgriff23/btw")
library("btw")

#Code to prepare an analysis in BayesTraits from a Beast2 derived phylogeny

#Tree file#
is_trees_file("Tree.trees") #returns a "True" or "False" if your .trees file is correctly formatted.

AllBeastTrees<-parse_beast_trees("Tree.trees")

#save the last 1,000 trees in the posterior of the run
Last_1000_trees<-tail(AllBeastTrees,1000)

#Run BayesTraits analysis under righteous settings#


#BayesTraits can get stuck on one or a few trees during its sampling (poor mixing), this is especially problematic if those trees do not contain the clades you wish to analyze
# the BayesTraits manual recommends removing specific problem trees and to rerun#
subsetTrees<-Last_1000_trees[c(-60,-889)]

#This analysis found one additonal problematic tree which was removed
subsetTrees2<-subsetTrees[-735]

#save subsetted trees to nexus format for BayesTraits.

writeNexus(Last_1000_trees, file="Sabertooth_1k.nexus")

#save subsetted trees v. 2 to nexus format for BayesTraits.
writeNexus(subsetTrees, file="Sabertooth_998.nexus")

#save subsetted trees v. 3 to nexus format for BayesTraits.
writeNexus(subsetTrees2, file="Sabertooth_997.nexus")


#import run results#

library(phyloch) #has to be downloaded from author's website
beast_tree<-read.beast("Cipres_100_MCC.tree")
beast_tree


#Parsing Bayestraits output#

BT_log<-parse_log("TNT_synaps_2.0.txt.Log_NA.txt") # "--" values were replaced with NAs

#Can retrieve the mean value of each probability of a state for a node via:

mean(BT_log$results$RecNode1...S.0....P.0.,na.rm=TRUE)

mean(BT_log$results$RecNode1...S.0....P.1.,na.rm=TRUE)

mean(BT_log$results$RecNode1...S.0....P.2.,na.rm=TRUE)

mean(BT_log$results$RecNode1...S.0....P.3.,na.rm=TRUE)



#APE Node Numbers#
ntips = length(beast_tree$tip.label)
Rnodenums = (ntips+1):(ntips+beast_tree$Nnode)
tipnums = 1:ntips
plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()
tiplabels(cex=0.5)
nodelabels(text=Rnodenums, node=Rnodenums, cex=0.5)
title("APE node numbers")

#node=c(node numbers as determined above)#
nodes<-c(65,66,80,69,88)


################################






#crude way of calculating node values for pies 'S', numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.0....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.0....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.0....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.0....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.0....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.0....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.0....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.0....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.0....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.0....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.0....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.0....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.0....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.0....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.0....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.0....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.0....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.0....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.0....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.0....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88)

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,1]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!







pdffn = "Synapomorphy 1.pdf"
pdf(file=pdffn, width=9, height=12)

plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
                              #this line of code gives the options that line up with tip label colors and the additional states of the Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 1")

#############################################

node65<-c(mean(BT_log$results$RecNode1...S.1....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.1....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.1....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.1....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.1....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.1....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.1....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.1....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.1....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.1....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.1....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.1....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.1....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.1....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.1....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.1....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.1....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.1....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.1....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.1....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88)

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,2]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","01","1","2","3"),colors=palette()[c(1:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 4")



##################################

##################################


#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.2....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.2....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.2....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.2....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.2....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.2....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.2....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.2....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.2....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.2....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.2....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.2....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.2....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.2....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.2....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.2....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.2....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.2....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.2....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.2....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,3]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","01","1","2","3"),colors=palette()[c(1:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 6")





########################################



#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.3....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.3....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.3....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.3....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.3....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.3....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.3....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.3....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.3....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.3....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.3....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.3....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.3....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.3....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.3....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.3....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.3....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.3....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.3....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.3....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,4]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 10")



#######################################################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.4....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.4....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.4....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.4....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.4....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.4....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.4....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.4....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.4....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.4....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.4....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.4....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.4....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.4....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.4....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.4....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.4....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.4....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.4....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.4....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,5]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 12")

##########################################################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.5....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.5....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.5....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.5....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.5....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.5....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.5....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.5....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.5....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.5....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.5....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.5....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.5....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.5....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.5....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.5....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.5....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.5....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.5....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.5....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,6]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 13")

#################################################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.6....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.6....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.6....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.6....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.6....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.6....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.6....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.6....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.6....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.6....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.6....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.6....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.6....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.6....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.6....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.6....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.6....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.6....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.6....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.6....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,7]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 14")

#################################################################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.7....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.7....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.7....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.7....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.7....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.7....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.7....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.7....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.7....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.7....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.7....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.7....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.7....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.7....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.7....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.7....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.7....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.7....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.7....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.7....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,8]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 17")

##################################################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.8....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.8....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.8....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.8....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.8....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.8....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.8....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.8....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.8....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.8....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.8....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.8....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.8....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.8....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.8....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.8....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.8....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.8....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.8....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.8....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,9]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 18")

#####################################################################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.9....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.9....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.9....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.9....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.9....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.9....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.9....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.9....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.9....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.9....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.9....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.9....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.9....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.9....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.9....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.9....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.9....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.9....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.9....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.9....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,10]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]

#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 22")


############################################################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.10....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.10....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.10....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.10....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.10....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.10....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.10....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.10....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.10....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.10....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.10....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.10....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.10....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.10....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.10....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.10....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.10....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.10....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.10....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.10....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,11]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2,4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","01","1","2","3"),colors=palette()[c(1:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 23")

##########################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.11....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.11....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.11....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.11....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.11....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.11....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.11....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.11....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.11....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.11....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.11....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.11....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.11....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.11....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.11....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.11....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.11....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.11....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.11....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.11....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,12]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 24")

###################################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.12....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.12....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.12....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.12....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.12....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.12....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.12....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.12....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.12....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.12....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.12....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.12....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.12....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.12....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.12....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.12....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.12....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.12....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.12....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.12....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,13]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 26")

###################################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.13....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.13....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.13....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.13....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.13....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.13....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.13....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.13....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.13....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.13....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.13....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.13....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.13....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.13....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.13....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.13....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.13....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.13....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.13....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.13....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,14]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 27")

############################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.14....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.14....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.14....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.14....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.14....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.14....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.14....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.14....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.14....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.14....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.14....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.14....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.14....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.14....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.14....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.14....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.14....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.14....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.14....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.14....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,15]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 28")

##############################################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.15....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.15....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.15....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.15....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.15....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.15....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.15....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.15....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.15....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.15....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.15....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.15....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.15....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.15....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.15....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.15....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.15....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.15....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.15....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.15....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,16]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 39")

#####################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.16....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.16....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.16....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.16....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.16....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.16....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.16....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.16....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.16....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.16....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.16....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.16....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.16....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.16....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.16....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.16....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.16....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.16....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.16....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.16....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,17]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 40")

###############################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.17....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.17....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.17....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.17....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.17....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.17....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.17....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.17....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.17....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.17....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.17....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.17....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.17....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.17....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.17....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.17....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.17....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.17....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.17....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.17....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,18]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 41")

######################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.18....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.18....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.18....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.18....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.18....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.18....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.18....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.18....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.18....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.18....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.18....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.18....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.18....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.18....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.18....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.18....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.18....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.18....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.18....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.18....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,19]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 44")

######################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.19....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.19....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.19....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.19....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.19....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.19....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.19....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.19....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.19....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.19....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.19....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.19....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.19....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.19....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.19....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.19....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.19....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.19....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.19....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.19....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,20]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 47")

##################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.20....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.20....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.20....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.20....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.20....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.20....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.20....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.20....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.20....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.20....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.20....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.20....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.20....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.20....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.20....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.20....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.20....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.20....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.20....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.20....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,21]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 49")

##################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.21....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.21....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.21....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.21....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.21....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.21....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.21....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.21....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.21....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.21....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.21....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.21....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.21....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.21....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.21....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.21....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.21....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.21....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.21....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.21....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,22]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 50")

#############################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.22....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.22....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.22....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.22....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.22....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.22....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.22....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.22....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.22....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.22....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.22....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.22....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.22....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.22....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.22....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.22....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.22....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.22....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.22....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.22....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,23]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:5)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2,4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","01","1","2","3"),colors=palette()[c(1:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 56")

####################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.23....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.23....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.23....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.23....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.23....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.23....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.23....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.23....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.23....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.23....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.23....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.23....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.23....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.23....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.23....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.23....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.23....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.23....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.23....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.23....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,24]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 57")

##########################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.24....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.24....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.24....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.24....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.24....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.24....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.24....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.24....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.24....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.24....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.24....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.24....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.24....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.24....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.24....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.24....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.24....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.24....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.24....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.24....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,25]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2,4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","01","1","2","3"),colors=palette()[c(1:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 58")

###########################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.25....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.25....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.25....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.25....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.25....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.25....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.25....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.25....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.25....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.25....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.25....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.25....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.25....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.25....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.25....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.25....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.25....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.25....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.25....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.25....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,26]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4:6)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 65")

##################################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.26....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.26....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.26....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.26....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.26....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.26....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.26....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.26....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.26....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.26....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.26....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.26....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.26....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.26....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.26....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.26....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.26....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.26....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.26....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.26....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,27]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","01","1","2","3"),colors=palette()[c(1:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 66")
#############################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.27....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.27....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.27....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.27....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.27....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.27....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.27....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.27....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.27....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.27....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.27....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.27....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.27....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.27....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.27....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.27....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.27....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.27....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.27....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.27....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,28]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 82")

#############################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.28....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.28....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.28....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.28....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.28....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.28....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.28....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.28....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.28....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.28....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.28....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.28....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.28....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.28....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.28....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.28....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.28....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.28....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.28....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.28....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,29]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 137")

##########################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.29....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.29....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.29....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.29....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.29....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.29....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.29....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.29....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.29....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.29....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.29....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.29....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.29....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.29....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.29....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.29....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.29....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.29....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.29....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.29....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,30]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 142")

##############################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.30....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.30....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.30....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.30....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.30....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.30....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.30....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.30....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.30....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.30....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.30....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.30....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.30....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.30....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.30....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.30....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.30....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.30....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.30....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.30....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,31]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 146")

########################################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.31....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.31....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.31....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.31....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.31....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.31....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.31....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.31....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.31....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.31....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.31....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.31....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.31....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.31....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.31....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.31....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.31....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.31....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.31....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.31....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,32]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 179")
########################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.32....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.32....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.32....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.32....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.32....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.32....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.32....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.32....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.32....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.32....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.32....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.32....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.32....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.32....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.32....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.32....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.32....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.32....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.32....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.32....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,33]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 183")
##############################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.33....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.33....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.33....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.33....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.33....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.33....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.33....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.33....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.33....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.33....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.33....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.33....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.33....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.33....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.33....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.33....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.33....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.33....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.33....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.33....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,34]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 209")

############################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.34....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.34....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.34....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.34....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.34....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.34....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.34....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.34....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.34....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.34....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.34....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.34....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.34....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.34....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.34....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.34....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.34....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.34....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.34....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.34....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,35]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 212")
##########################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.35....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.35....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.35....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.35....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.35....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.35....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.35....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.35....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.35....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.35....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.35....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.35....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.35....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.35....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.35....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.35....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.35....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.35....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.35....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.35....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,36]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","01","1","2","3"),colors=palette()[c(1:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 217")
#############################

#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.36....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.36....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.36....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.36....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.36....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.36....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.36....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.36....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.36....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.36....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.36....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.36....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.36....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.36....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.36....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.36....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.36....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.36....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.36....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.36....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,37]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","01","1","2","3"),colors=palette()[c(1:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 218")
###############################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.37....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.37....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.37....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.37....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.37....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.37....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.37....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.37....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.37....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.37....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.37....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.37....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.37....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.37....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.37....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.37....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.37....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.37....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.37....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.37....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,38]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 220")
####################################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.38....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.38....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.38....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.38....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.38....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.38....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.38....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.38....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.38....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.38....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.38....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.38....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.38....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.38....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.38....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.38....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.38....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.38....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.38....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.38....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,39]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 221")
##################################
#crude way of calculating node values for pies S is trait number, but numbering starts at 0
node65<-c(mean(BT_log$results$RecNode1...S.39....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.39....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.39....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode1...S.39....P.3.,na.rm=TRUE))
node66<-c(mean(BT_log$results$RecNode2...S.39....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.39....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.39....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode2...S.39....P.3.,na.rm=TRUE))
node80<-c(mean(BT_log$results$RecNode3...S.39....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.39....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.39....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode3...S.39....P.3.,na.rm=TRUE))
node69<-c(mean(BT_log$results$RecNode4...S.39....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.39....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.39....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode4...S.39....P.3.,na.rm=TRUE))
node88<-c(mean(BT_log$results$RecNode5...S.39....P.0.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.39....P.1.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.39....P.2.,na.rm=TRUE),
          mean(BT_log$results$RecNode5...S.39....P.3.,na.rm=TRUE))

pies<-matrix(c(node65, node66, node80, node69, node88), nrow=5, ncol=4, byrow = TRUE)
colnames(pies) <- c("0", "1", "2", "3")
rownames(pies) <- c(65, 66, 80, 69, 88 )

#Notes on Bayestraits treatment of traits: missing data are treated as if the trait could take any of the other states, with equal probability. Polymorphic traits 
# such as "BC" signifies that it can be instates B or C (with equal probability) but not in state A.


#Correct tip, node and legend plotting
#1st trait
x<-as.matrix(read.table("TNT_synaps_2.0.txt",row.names=1))[,40]
x<-to.matrix(x,sort(unique(x)))

#aligns tip data with tips of tree
x<-x[beast_tree$tip.label,]
x
#cols<-setNames(palette()[1:length(unique(x))],sort(unique(x)))

tip_cols<-palette()[c(1:2,4)] #This varies depending on how many ?, states or polymorphisms a trait has!






plot(beast_tree, label.offset=0.25, cex=0.5)
axisPhylo()


tiplabels(pie=x,piecol=tip_cols,cex=0.3)


node_cols<-palette()[c(2, 4:6)]  #the "-" isn't a probability output of the Bayestraits analysis, as discussed above
#this line of code gives the options that line up with tip label colors and the additional states of teh Bayestraits analysis



nodelabels(node=nodes,
           pie=pies,piecol=node_cols,cex=0.5)


add.simmap.legend(leg=c("?","0","1","2","3"),colors=palette()[c(1:2,4:6)],prompt=FALSE,x=0.9*par()$usr[1],
                  y=20,fsize=0.8)


title("Synapomorphy 222")


dev.off()